brm

package module
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 7 Imported by: 0

README

brm

installation

go install github.com/Vardhanb07/brm/cmd/brm@latest

help

brm --help

will tell you everything you need

uninstall

sudo rm "$(which brm)"

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckTrashDir

func CheckTrashDir(trashDir string) bool

checks if trash dir exits

func DefaultTrashDir

func DefaultTrashDir() string

gets default trash dir

func GetFileOrLinkStats

func GetFileOrLinkStats(path string) (os.FileInfo, error)

func PathResolve

func PathResolve(path string) (string, error)

resolves path to abs path deals path starting with ~, ../, ./

func Remove

func Remove(fpath string, trashdir string, verbose bool, noSave bool, out io.Writer) error

removes file and places it in trash directory

func RemoveDir

func RemoveDir(dir string, trashDir string, verbose bool, noSave bool, out io.Writer) error

removes dir and it's contents

func Update

func Update(verbose bool, out io.Writer) error

this operation will wait for 5 seconds since its a network call and then cancel

Types

This section is empty.

Directories

Path Synopsis
cmd
brm command

Jump to